from ..exception.service_exception import (
    raise_request_validation_error as raise_request_validation_error,
)
from ..schemas.query_request import (
    Condition as Condition,
    QueryLogicOperation as QueryLogicOperation,
    QueryRequest as QueryRequest,
    QuerySimpleCondition as QuerySimpleCondition,
)
from ..type.var import SQLModelDB as SQLModelDB, SQLModelResponse as SQLModelResponse
from .query_field import (
    convert_datetime_iso_to_standard as convert_datetime_iso_to_standard,
    get_class_fields_with_sa_type as get_class_fields_with_sa_type,
)
from .tenant_checker import TenantManager as TenantManager
from sqlmodel import SQLModel as SQLModel
from typing import Any

class QueryBuilder:
    """将 QueryRequest 转换为 SQLModel 查询条件"""
    @classmethod
    def build_list(
        cls,
        query_fields,
        items,
        model_class: type[SQLModelDB],
        response_class: type[SQLModelResponse] = None,
    ): ...
    @staticmethod
    def get_order_by(query: QueryRequest, model_class: type[SQLModel]) -> Any: ...
    @classmethod
    def get_fields(cls, query: QueryRequest, model_class: type[SQLModel]) -> Any: ...
    @classmethod
    def get_where(cls, condition: Condition, model_class: type[SQLModel]) -> Any: ...
    @staticmethod
    def get_condition_python_value(field, field_type, field_value): ...
    @classmethod
    def method_name(cls, fields, item, tag) -> None: ...
    @classmethod
    def build_tree(cls, items, *, query: QueryRequest, model_class, response_class): ...
    @classmethod
    def check_query_request(cls, query) -> None: ...



from ..enum.label_enum import LabelEnum as LabelEnum
from ..enum.resolve_enum import resolve_enum_field as resolve_enum_field

class EnumService:
    """枚举解析服务类。
    提供统一接口，用于将字典中的原始字段值（如字符串或整数）解析为对应的枚举实例，
    通常用于数据反序列化、API 输入校验或数据库记录映射等场景。
    """
    @classmethod
    def resolve_field(
        cls, data: dict, field_name: str, enum_cls: type[LabelEnum]
    ) -> None:
        """将字典中指定字段的值解析为对应的 LabelEnum 枚举实例。"""



from .. import get_engine_name as get_engine_name, get_schema_name as get_schema_name
from ...controller.table_controller import AuthController as AuthController
from ..entity_table.t_enum_schema import (
    TEnumSchema as TEnumSchema,
    TEnumSchemaCreate as TEnumSchemaCreate,
    TEnumSchemaResponse as TEnumSchemaResponse,
    TEnumSchemaUpdate as TEnumSchemaUpdate,
)
from _typeshed import Incomplete

TEnumSchema_Router: Incomplete



#!/usr/bin/env python3
# -*- coding:utf-8 -*-
# @License  ：(C)Copyright 2025, 数道智融科技

from sqlalchemy.orm import registry
from sqlmodel import SQLModel

from ..config.running_config import RunningConfig
from ..engine.database_engine import DatabaseEngine

auth_registry = registry()


class RegistryModel(SQLModel, registry=auth_registry):
    ...


# 用于 Controller
def get_engine_name():
    return RunningConfig.get_engine_name("Auth", "shudaodao_auth")


# noinspection DuplicatedCode
setattr(auth_registry, "engine_name", get_engine_name())


# 用于 Controller
def get_schema_name():
    return RunningConfig.get_controller_schema("shudaodao_auth")


# SQLModel 类: __table_args__ = {"schema": "用于这里"}
def get_table_schema():
    if DatabaseEngine().support_schema(name=get_engine_name()):
        return RunningConfig.get_sqlmodel_schema("shudaodao_auth")
    return None


# SQLModel 类: foreign_key= 用于这里 -> schema_name.t_table_name.field_id"
def get_foreign_schema():
    table_schema = get_table_schema()
    return table_schema + "." if table_schema else ""



def get_class_fields_with_sa_type(model_class, sa_type): ...
def convert_datetime_iso_to_standard(dt_str):
    """
    将 ISO 8601 格式（含T）的时间字符串转换为 'YYYY-MM-DD HH:MM:SS' 格式
    支持：2025-09-22T10:30:00, 2025-09-22T10:30:00Z, 2025-09-22T10:30:00+08:00 等
    """



from enum import IntEnum

class LabelEnum(IntEnum):
    def __new__(cls, value: int, label: str, description: str = ""): ...
    @classmethod
    def from_label(cls, label: str):
        """根据 label 查找枚举成员"""
    @classmethod
    def labels(cls) -> list[str]:
        """获取所有标签"""
    @property
    def label(self) -> str: ...
    @property
    def description(self) -> str: ...



from .. import get_engine_name as get_engine_name, get_schema_name as get_schema_name
from ...controller.table_controller import AuthController as AuthController
from ..entity_table.t_enum_field import (
    TEnumField as TEnumField,
    TEnumFieldCreate as TEnumFieldCreate,
    TEnumFieldResponse as TEnumFieldResponse,
    TEnumFieldUpdate as TEnumFieldUpdate,
)
from _typeshed import Incomplete

TEnumField_Router: Incomplete
